/*
 * Copyright (c) 1998-2004 Matthijs Hollemans
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef GREPWINDOW_H
#define GREPWINDOW_H

class Grepper;

class GrepWindow : public BWindow
{
public:

	GrepWindow();
	virtual ~GrepWindow();

	virtual void FrameResized(float width, float height);
	virtual void FrameMoved(BPoint origin);
	virtual void MenusBeginning();
	virtual void MenusEnded();
	virtual void MessageReceived(BMessage* msg);

private:

	typedef BWindow super;

	void SetWindowTitle();
	void CreateOptionsMenu();
	void CreateViews();
	void LayoutViews();

	void LoadPrefs();
	void SavePrefs();

	void OnStartCancel();
	void OnSearchFinished();
	void OnReportFileName(BMessage* msg);
	void OnReportResult(BMessage* msg);
	void OnReportError(BMessage* msg);
	void OnRecurseLinks();
	void OnRecurseDirs();
	void OnCaseSensitive();
	void OnEscapeText();
	void OnTextOnly();
	void OnInvokePe();
	void OnShowContents();
	void OnInvokeItem();
	void OnSearchText();
	void OnHistoryItem(BMessage* msg);

	void OpenInPe(const entry_ref& ref, int32 lineNum);

	BTextControl* searchText;
	BOutlineListView* searchResults;
	BMenuField* historyMenu;
	BMenuField* optionsMenu;
	BMenuItem* recurseLinks;
	BMenuItem* recurseDirs;
	BMenuItem* caseSensitive;
	BMenuItem* escapeText;
	BMenuItem* textOnly;
	BMenuItem* invokePe;
	BCheckBox* showContents;
	BButton* button;

	Grepper* grepper;
	char* oldPattern;
};

#endif // GREPWINDOW_H
