/*
 * Copyright (c) 1998-2004 Matthijs Hollemans
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef MODEL_H
#define MODEL_H

#define VERSION       "4.1"

#define SETTINGS_DIR  "/boot/home/config/settings/"
#define PREFS_FILE    SETTINGS_DIR "TrackerGrepSettings"
#define HISTORY_FILE  SETTINGS_DIR "TrackerGrepHistory"

#define HISTORY_LIMIT  20

enum
{
	MSG_START_CANCEL = 1000,
	MSG_RECURSE_LINKS,
	MSG_RECURSE_DIRS,
	MSG_CASE_SENSITIVE,
	MSG_ESCAPE_TEXT,
	MSG_TEXT_ONLY,
	MSG_INVOKE_PE,
	MSG_SHOW_CONTENTS,
	MSG_SEARCH_TEXT,
	MSG_INVOKE_ITEM,
	MSG_SELECT_HISTORY,

	MSG_REPORT_FILE_NAME,
	MSG_REPORT_RESULT,
	MSG_REPORT_ERROR,
	MSG_SEARCH_FINISHED,
};

enum state_t
{
	STATE_IDLE = 0,
	STATE_SEARCH,
	STATE_CANCEL,
};

class Model
{
public:

	Model();

	void LoadPrefs();
	void SavePrefs();

	void AddToHistory(const char* text);
	void FillHistoryMenu(BMenu* menu);

	// The directory we were invoked from.
	entry_ref directory;

	// The selected files we were invoked upon.
	BMessage* selectedFiles;

	// Whether we need to look into subdirectories.
	bool recurseDirs;
	
	// Whether we need to follow symbolic links.
	bool recurseLinks;
	
	// Whether the search is case sensitive.
	bool caseSensitive;

	// Whether the search pattern will be escaped.
	bool escapeText;
	
	// Whether we look at text files only.
	bool textOnly;
	
	// Whether we open the item in Pe and jump to the correct line.
	bool invokePe;
	
	// Whether to show the contents of matching files.
	bool showContents;

	// The dimensions of the window.
	BRect frame;

	// The looper that will receive notifications.
	BLooper* target;

	// What are we doing.
	state_t state;

private:

	BList* LoadHistory();
	void SaveHistory(BList* items);
	void FreeHistory(BList* items);
};

extern Model model;

#endif // MODEL_H
