/*
 * Copyright (c) 1998-2004 Matthijs Hollemans
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

#include <TrackerAddon.h>
#include <Application.h>
#include <Alert.h>
#include <Entry.h>

#include "Model.h"
#include "GrepWindow.h"

////////////////////////////////////////////////////////////////////////////////

static void ShowAboutWindow()
{
	(new BAlert(
		NULL,
		"Tracker Grep " VERSION
		"\nUse grep from the Tracker\n\n"
		"Created by Matthijs Hollemans\n"
		"mahlzeit@users.sf.net\n\n"
		"Thanks to Peter Hinely, Serge Fantino,\n"
		"Hideki Naito, and Oscar Lesta.\n",
		"Okay",
		NULL,
		NULL,
		B_WIDTH_AS_USUAL,
		B_INFO_ALERT))->Go();
}

////////////////////////////////////////////////////////////////////////////////

void process_refs(entry_ref directory, BMessage* message, void* reserved) 
{ 
	// Tracker calls this function when the user invokes the add-on. 
	// "directory" contains the entry_ref of the current directory. 
	// "message" is a standard B_REFS_RECEIVED BMessage whose "refs" 
	// array contains the entry_refs of the selected files. The last
	// argument, "reserved", is currently unused.

	model.directory = directory;
	model.selectedFiles = message;
	
	GrepWindow* window = new GrepWindow;

	// Wait until the window thread terminates. If we don't do this,
	// our add-on might crash mysteriously, taking the Tracker with
	// it. See also "Be Newsletter Volume II Issue 10".

	int32 exitValue;
	wait_for_thread(window->Thread(), &exitValue);
} 
 
////////////////////////////////////////////////////////////////////////////////

int main() 
{
	// An add-on is not required to have a main() function. But if it
	// does, the user can run the add-on as a stand-alone application
	// as well. We just show a simple about window.

	BApplication app("application/x-vnd.mahlzeit.trackergrep");
	ShowAboutWindow();
	return 0;
}

////////////////////////////////////////////////////////////////////////////////
